# -*- coding: utf-8 -*-
from zope.interface import Interface

class IClassifiedsCategory(Interface):
    """Marker interface for .ClassifiedsCategory.ClassifiedsCategory
    """

class IClassifieds(Interface):
    """Marker interface for .Classifieds.Classifieds
    """

class IClassified(Interface):
    """Marker interface for .Classified.Classified
    """

class IOrderedClassifieds(Interface):
    """Marker interface for .Classifieds.Classifieds
    """


class IOrderedClassifiedsCategory(Interface):
    """Marker interface for .OrderedClassifiedsCategory.OrderedClassifiedsCategory
    """
